# Generated by ariadne-codegen on 2024-03-06 08:19
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SlimCustomerFragment


class DetachCustomerPaymentMethod(BaseModel):
    detach_customer_payment_method: "DetachCustomerPaymentMethodDetachCustomerPaymentMethod" = Field(
        alias="detachCustomerPaymentMethod"
    )


class DetachCustomerPaymentMethodDetachCustomerPaymentMethod(SlimCustomerFragment):
    pass


DetachCustomerPaymentMethod.update_forward_refs()
DetachCustomerPaymentMethodDetachCustomerPaymentMethod.update_forward_refs()



# Generated by ariadne-codegen on 2024-03-06 08:19
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SubscriptionPreviewFragment


class EstimateSubscription(BaseModel):
    estimate_subscription: "EstimateSubscriptionEstimateSubscription" = Field(
        alias="estimateSubscription"
    )


class EstimateSubscriptionEstimateSubscription(SubscriptionPreviewFragment):
    pass


EstimateSubscription.update_forward_refs()
EstimateSubscriptionEstimateSubscription.update_forward_refs()
